import pandapipes as pp
import networkx as nx

def gen_model_pp_from_nx(
        g=nx.Graph()
       ,fluid='water'
):
    """ Returns a pandapipes model from a networkx graph."""

    pass

    net = pp.create_empty_network(fluid=fluid)

    return net 


#from distutils.core import setup # type: ignore
from setuptools import setup#, find_packages

setup(name='pnh',
      version='0.0.2',
      description='pnh',
      packages=['pnh','utils'],#find_packages(),
      package_dir={
       'pnh':'.','utils':'utils'},
     )